/*
    Bear Engine - Level editor

    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    contact: plee-the-bear@gamned.org

    Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file bf/history/action_add_item.hpp
 * \brief The action of adding an item in a layer.
 * \author Julien Jorge
 */
#ifndef __BF_ACTION_ADD_ITEM_HPP__
#define __BF_ACTION_ADD_ITEM_HPP__

#include "bf/history/level_action.hpp"

namespace bf
{
  class item_instance;

  /**
   * \brief The action of adding an item in a layer.
   * \author Julien Jorge
   */
  class action_add_item:
    public level_action
  {
  public:
    /**
     * \brief Constructor.
     * \param item The item to add.
     * \param lay The layer in which the item is added.
     */
    action_add_item( item_instance* item, unsigned int lay );

    /** \brief Destructor. */
    ~action_add_item();

    void execute( gui_level& lvl );
    void undo( gui_level& lvl );

    bool is_identity( const gui_level& gui ) const;
    wxString get_description() const;

  private:
    /** \brief The item to add. */
    item_instance* const m_item;

    /** \brief The layer in which the item is added. */
    const unsigned int m_layer;

    /** \brief Tell if the action has been done or not. */
    bool m_done;

  }; // class action_add_item
} // namespace bf

#endif // __BF_ACTION_ADD_ITEM_HPP__
