/*
    Bear Engine - Level editor

    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    contact: plee-the-bear@gamned.org

    Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file bf/history/action_add_layer.hpp
 * \brief The action of adding layer in a level.
 * \author Julien Jorge
 */
#ifndef __BF_ACTION_ADD_LAYER_HPP__
#define __BF_ACTION_ADD_LAYER_HPP__

#include "bf/history/level_action.hpp"

namespace bf
{
  class layer;

  /**
   * \brief The action of adding a layer in a level.
   * \author Julien Jorge
   */
  class action_add_layer:
    public level_action
  {
  public:
    /**
     * \brief Constructor.
     * \param lay The layer to add.
     * \param index The index of the layer in the level.
     */
    action_add_layer( layer* lay, unsigned int index );

    /** \brief Destructor. */
    ~action_add_layer();

    void execute( gui_level& lvl );
    void undo( gui_level& lvl );

    bool is_identity( const gui_level& gui ) const;
    wxString get_description() const;

  private:
    /** \brief The layer to add. */
    layer* m_layer;

    /** \brief The index of the layer in the level. */
    unsigned int m_index;

  }; // class action_add_layer
} // namespace bf

#endif // __BF_ACTION_ADD_LAYER_HPP__
