/*
    Bear Engine - Model editor

    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    contact: plee-the-bear@gamned.org

    Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file bf/history/action_modify_function.hpp
 * \brief The action of modify the function called in a snapshot.
 * \author Sbastien Angibaud
 */
#ifndef __BF_ACTION_MODIFY_FUNCTION_HPP__
#define __BF_ACTION_MODIFY_FUNCTION_HPP__

#include "bf/history/model_action.hpp"
#include "bf/any_animation_edit.hpp"

#include <string>

namespace bf
{
  class snapshot;

  /**
   * \brief The action of modify the function called in a snapshot.
   * \author Sbastien Angibaud
   */
  class action_modify_function:
    public model_action
  {
  public:
    /**
     * \brief Constructor.
     * \param s The snapshot to consider.
     * \param function The new function of the snapshot.
     */
    action_modify_function
    ( snapshot* s, const std::string& function);

    /**
     * \remark Calling execute() two times will restore the initial size.
     */
    void execute( gui_model& mdl );
    void undo( gui_model& mdl );

    bool is_identity( const gui_model& gui ) const;
    wxString get_description() const;

  private:
    /** \brief The snapshot to modify. */
    snapshot* m_snapshot;

    /** \brief The new function of the snapshot. */
    std::string m_function;
  }; // class action_modify_function
} // namespace bf

#endif // __BF_ACTION_MODIFY_FUNCTION_HPP__
